from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name ="RJcalculator",
    version = "0.0.2",
    description = "A very basic calculator",
    # long_description = open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    author = 'Rachit Jain',
    author_email = 'jrachit012@gmail.com',
    License = 'MIT',
    classifiers = classifiers,
    keywords = 'calculator',
    packages = find_packages(),
    install_requires = []
)
    


# class Operations:

def add(x, y):
    return x + y

def subtract(x, y):
    return x - y

def multiply(x, y):
    return x * y

def divide(x, y):
    return x / y

def power(x, y):
    return x ** y